==> atutor-1.6.1a.tbz: www/atutor/documentation/admin/pages.inc.php <==
<?php
// the order matters, b/c it what generates the prev/next links
	$_pages = array();
	$_pages['introduction.php']                  = 'Introduction';
	$_pages['installation.php']                  = 'Installation';
	$_pages['requirements_recommendations.php']  = 'Requirements &amp; Recommendations';
	$_pages['new_installation.php']              = 'New Installation';
	$_pages['upgrading.php']                     = 'Upgrading an Installation';
	$_pages['configuration.php']                 = 'Administrator Home';
	$_pages['my_account.php']                    = 'My Account';
	$_pages['system_preferences.php']            = 'System Preferences';
	$_pages['default_preferences.php']			 = 'Default Preferences';
	$_pages['languages.php']                     = 'Languages';
	$_pages['themes.php']                        = 'Themes';
	$_pages['importing_themes.php']              = 'Importing/Exporting Themes';
	$_pages['managing_existing_themes.php']		 = 'Managing Existing Themes';
	$_pages['creating_themes.php']               = 'Creating Themes';
	$_pages['error_logging.php']                 = 'Error Logging';
	$_pages['feeds.php']						 = 'Syndicated Feeds';
	$_pages['google_key.php']					 = 'Google Key';
	$_pages['cron_setup.php']					 = 'Cron Set-up';
	$_pages['enrollment.php']                    = 'Enrollment';
	$_pages['enrollment_privileges.php']         = 'Privileges';
	$_pages['users.php']                         = 'Users';
	$_pages['instructor_requests.php']           = 'Instructor Requests';
	$_pages['master_student_list.php']           = 'Master Student List';
	$_pages['email_users.php']                   = 'Email Users';
	$_pages['administrators.php']                = 'Administrators';
	$_pages['courses.php']                       = 'Courses';
	$_pages['creating_courses.php']              = 'Creating Courses';
	$_pages['default_student_tools.php']         = 'Default Student Tools';
	$_pages['default_side_menu.php']			 = 'Default Side Menu';
	$_pages['backups.php']                       = 'Backups';
	$_pages['forums.php']                        = 'Forums';
	$_pages['auto_enroll.php']                        = 'Auto-Enroll at Registration';
	$_pages['categories.php']                    = 'Course Categories';
	$_pages['modules.php']                       = 'Modules';
	$_pages['patcher.php']                       = 'Patcher';
	$_pages['create_patches.php']                = 'Create Patches';
	$_pages['troubleshooting.php']               = 'Troubleshooting';
?>

==> atutor-2.0.2.tbz: www/atutor/documentation/admin/pages.inc.php <==
<?php
// the order matters, b/c it what generates the prev/next links
	$_pages = array();
	$_pages['introduction.php']                  = 'Introduction';
	$_pages['installation.php']                  = 'Installation';
	$_pages['requirements_recommendations.php']  = 'Requirements &amp; Recommendations';
	$_pages['new_installation.php']              = 'New Installation';
	$_pages['upgrading.php']                     = 'Upgrading an Installation';
	$_pages['configuration.php']                 = 'Administrator Home';
	$_pages['my_account.php']                    = 'My Account';
	$_pages['system_preferences.php']            = 'System Preferences';
	$_pages['default_preferences.php']			 = 'Default Preferences';
	$_pages['languages.php']                     = 'Languages';
	$_pages['themes.php']                        = 'Themes';
	$_pages['importing_themes.php']              = 'Importing/Exporting Themes';
	$_pages['managing_existing_themes.php']		 = 'Managing Existing Themes';
	$_pages['creating_themes.php']               = 'Creating Themes';
	$_pages['error_logging.php']                 = 'Error Logging';
	$_pages['feeds.php']						 = 'News Feeds';
	$_pages['google_key.php']					 = 'Google Key';
	$_pages['cron_setup.php']					 = 'Cron Set-up';
	$_pages['enrollment.php']                    = 'Enrollment';
	$_pages['enrollment_privileges.php']         = 'Privileges';
	$_pages['users.php']                         = 'Users';
	$_pages['instructor_requests.php']           = 'Instructor Requests';
	$_pages['master_student_list.php']           = 'Master Student List';
	$_pages['email_users.php']                   = 'Email Users';
	$_pages['administrators.php']                = 'Administrators';
	$_pages['courses.php']                       = 'Courses';
	$_pages['creating_courses.php']              = 'Creating Courses';
	$_pages['default_student_tools.php']         = 'Default Course Tools';
	$_pages['default_side_menu.php']	     = 'Default Side Menu';
	$_pages['backups.php']                       = 'Backups';
	$_pages['forums.php']                        = 'Forums';
	$_pages['auto_enroll.php']                        = 'Auto-Enrolment';
	$_pages['categories.php']                    = 'Course Categories';
	$_pages['modules.php']                       = 'Modules';
	$_pages['patcher.php']                       = 'Patcher';
	$_pages['create_patches.php']                = 'Create Patches';
	$_pages['troubleshooting.php']               = 'Troubleshooting';
?>
